import { ZodArray, ZodBoolean, ZodEnum, ZodNumber, ZodString, z, ZodDate, ZodObject, ZodEffects, ZodOptional, ZodNullable, ZodType } from 'zod';
import { Entity } from '../../../types';
import { FieldWithType, PropsForField, TypeField } from '../../orm';
declare const getZodSchemaForJson: (isNull: boolean) => z.ZodUnion<[z.ZodUnion<[z.ZodTypeAny, z.ZodTypeAny, ...z.ZodTypeAny[]]>, ZodArray<z.ZodUnion<[z.ZodTypeAny, z.ZodTypeAny, ...z.ZodTypeAny[]]>, "many">, z.ZodRecord<ZodString, z.ZodUnion<[z.ZodTypeAny, z.ZodTypeAny, ...z.ZodTypeAny[]]>>]>;
type Literal = ReturnType<typeof getZodSchemaForJson>;
type Json = Literal | {
    [key: string]: Json;
} | Json[];
type ZodTypeForArray = ZodString | ZodDate | ZodEffects<ZodNumber, number, unknown> | ZodBoolean;
type ZodArrayType = ZodArray<ZodTypeForArray, 'many'> | ZodNullable<ZodArray<ZodTypeForArray, 'many'>>;
type TypeMapToZod = {
    [TypeField.array]: ZodOptional<ZodArrayType>;
    [TypeField.date]: ZodOptional<ZodDate | ZodNullable<ZodDate>>;
    [TypeField.number]: ZodOptional<ZodEffects<ZodNumber, number, unknown> | ZodNullable<ZodEffects<ZodNumber, number, unknown>>>;
    [TypeField.boolean]: ZodOptional<ZodBoolean | ZodNullable<ZodBoolean>>;
    [TypeField.string]: ZodOptional<ZodString | ZodEnum<[string, ...string[]]> | ZodNullable<ZodString | ZodEnum<[string, ...string[]]>>>;
    [TypeField.object]: ZodType<Json> | ZodNullable<ZodType<Json>>;
};
type ZodShapeAttributes<E extends Entity> = Omit<{
    [K in keyof FieldWithType<E>]: TypeMapToZod[FieldWithType<E>[K]];
}, 'id'>;
export type ZodAttributesSchema<E extends Entity> = ZodEffects<ZodObject<ZodShapeAttributes<E>, 'strict'>>;
export declare const zodAttributesSchema: <E extends Entity>(fieldWithType: FieldWithType<E>, propsDb: PropsForField<E>) => ZodAttributesSchema<E>;
export {};
